# TorchLiter
[![test](https://github.com/ChenchaoZhao/TorchLiter/actions/workflows/lint-test.yaml/badge.svg)](https://github.com/ChenchaoZhao/TorchLiter/actions/workflows/lint-test.yaml)

A freely customizable and truly lightweight training tool for any pytorch projects
## Install
```
pip install torchliter
```
